@@ -5,7 +5,8 @@
 #'
 #' @param Y.data The dataset after (at least) peak detection and grouping with speaq 2.0. The dataset after peak filling is recommended.
 #' @param var The variable to be used in the Featurematrix. This can be any of 'peakIndex', 'peakPPM', 'peakValue' (default), 'peakSNR', 'peakScale', or 'Sample'.
-#' @param impute What to impute when a certain peak is missing for a certain sample and feature combo. Options are 'zero' (or 'zeros'), median (imputation with median), randomForest (imputation with missForest function from package missForest) or kNN followed by a number indicating the amount of neighbours to use e.g. kNN5 or kNN10 (as per the method of Troyanskaya, 2001). Any other statement will produce NA's.
+#' @param impute What to impute when a certain peak is missing for a certain sample and feature combo. Options are "zero" (or "zeros", the default), "median" (imputation with feature median), "randomForest" (imputation with missForest function from package missForest) or kNN followed by a number indicating the amount of neighbours to use e.g. "kNN5" or "kNN10" (as per the method of Troyanskaya, 2001) or lasty "User_value" (this will allow the use of any value specified with the imputation_val argument e.g. the median of the raw spectra). Any other statement will produce NA's.
+#' @param imputation_val If the "User_value" imputation option is chosen this value will be used to impute the missing values.
 #' @param delete.below.threshold Whether to ignore peaks for which the 'var' variable has a value below 'baselineThresh' (default = FALSE).
 #' @param baselineThresh The threshold for the 'var' variable that peaks have to surpass to be included in the feature matrix.
 #' @param snrThres The threshold for the signal-to-noise ratio of a peak.
@@ -37,7 +38,7 @@
 #' @importFrom missForest missForest
 #' @importFrom impute impute.knn
 #' 
-BuildFeatureMatrix <- function(Y.data, var = "peakValue", impute = "zero", delete.below.threshold = FALSE, 
+BuildFeatureMatrix <- function(Y.data, var = "peakValue", impute = "zero", imputation_val = NA, delete.below.threshold = FALSE, 
     baselineThresh = 500, snrThres = 3, thresholds.pass = "any-to-pass") {
     if (!var %in% names(Y.data)) {
         stop("the variable of interest defined by 'var' is not in the names of the data")
@@ -120,6 +121,8 @@ BuildFeatureMatrix <- function(Y.data, var = "peakValue", impute = "zero", delet
         data.matrix <- impute::impute.knn(data.matrix, k = as.numeric(gsub("kNN","", impute)), rowmax = 0.5, colmax = 0.8, maxp = 1500)
     } else if (impute == "randomForest"){
         data.matrix <- missForest::missForest(data.matrix, verbose = FALSE)
+    } else if (impute == "User_value"){
+        data.matrix[is.na(data.matrix)] = imputation_val
     }
     
     
