@@ -75,7 +75,7 @@ dohClusterCustommedSegments <-function(X, peakList, refInd, segmentInfoMat,
         mysegments=c(1,segmentInfoMat[1,1]-1,0,0,0) else mysegments=c();
         i = 0;
         if (nrow(segmentInfoMat)>1){   
-            for (i in 1:(nrow(segmentInfoMat)-1)){
+            for (i in seq_len(nrow(segmentInfoMat)-1)){
                 mysegments=c(mysegments,c(segmentInfoMat[i,]))
                 if (segmentInfoMat[i+1,1]-segmentInfoMat[i,2]>minSegSize)
                     mysegments=c(mysegments,c(segmentInfoMat[i,2]+1,segmentInfoMat[i+1,1]-1,0,0,0))
@@ -100,7 +100,7 @@ dohClusterCustommedSegments <-function(X, peakList, refInd, segmentInfoMat,
         
         Y=X;
         
-        for (i in 1:nrow(mysegments))
+        for (i in seq_len(nrow(mysegments)))
             if (mysegments[i,3]!=0)
             {
                 if (verbose)
@@ -108,7 +108,7 @@ dohClusterCustommedSegments <-function(X, peakList, refInd, segmentInfoMat,
                         mysegments[i,1]," to ",mysegments[i,2]," ...");
                 
                 segmentpeakList=peakList;
-                for (j in 1:length(peakList)){
+                for (j in seq_along(peakList)){
                     segmentpeakList[[j]]=
                         findSegPeakList(peakList[[j]],mysegments[i,1],mysegments[i,2]);
                 }    
